"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = getPalette;
exports.hexToRgb = hexToRgb;
exports.OTHERS_COLOR = exports.NULL_COLOR = exports.DEFAULT_PALETTE = void 0;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var cartoColors = _interopRequireWildcard(require("cartocolor"));

var _utils = require("./utils");

var DEFAULT_PALETTE = 'PurpOr';
exports.DEFAULT_PALETTE = DEFAULT_PALETTE;
var NULL_COLOR = [204, 204, 204];
exports.NULL_COLOR = NULL_COLOR;
var OTHERS_COLOR = [119, 119, 119];
exports.OTHERS_COLOR = OTHERS_COLOR;

function getPalette(name, numCategories) {
  var palette = cartoColors[name];
  var paletteIndex = numCategories;
  (0, _utils.assert)(palette, "Palette \"".concat(name, "\" not found. Expected a CARTOColors string"));
  var palettesColorVariants = Object.keys(palette).filter(function (p) {
    return p !== 'tags';
  }).map(Number);
  var longestPaletteIndex = Math.max.apply(Math, (0, _toConsumableArray2["default"])(palettesColorVariants));
  var smallestPaletteIndex = Math.min.apply(Math, (0, _toConsumableArray2["default"])(palettesColorVariants));

  if (!Number.isInteger(numCategories) || numCategories > longestPaletteIndex) {
    paletteIndex = longestPaletteIndex;
  } else if (numCategories < smallestPaletteIndex) {
    paletteIndex = smallestPaletteIndex;
  }

  var colors = palette[paletteIndex];

  if (palette.tags && palette.tags.includes('qualitative')) {
    colors = colors.slice(0, -1);
  }

  return colors.map(function (c) {
    return hexToRgb(c);
  });
}

function hexToRgb(hex) {
  var result = /^#?([a-f\d]{1})([a-f\d]{1})([a-f\d]{1})$/i.exec(hex);

  if (result) {
    return [parseInt(result[1] + result[1], 16), parseInt(result[2] + result[2], 16), parseInt(result[3] + result[3], 16), 255];
  }

  result = /^#?([a-f\d]{1})([a-f\d]{1})([a-f\d]{1})([a-f\d]{1})$/i.exec(hex);

  if (result) {
    return [parseInt(result[1] + result[1], 16), parseInt(result[2] + result[2], 16), parseInt(result[3] + result[3], 16), parseInt(result[4] + result[4], 16)];
  }

  result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);

  if (result) {
    return [parseInt(result[1], 16), parseInt(result[2], 16), parseInt(result[3], 16), 255];
  }

  result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);

  if (result) {
    return [parseInt(result[1], 16), parseInt(result[2], 16), parseInt(result[3], 16), parseInt(result[4], 16)];
  }

  (0, _utils.assert)(result, "Hexadecimal color \"".concat(hex, "\" was not parsed correctly"));
  return NULL_COLOR;
}
//# sourceMappingURL=palette.js.map